@@ -66,7 +66,7 @@
   NSURL *quickLocation;
   NSURL *aclLocation;
   NSString *folderTypeName;
-  NSMutableArray *quickFieldNames;
+  NSMutableArray *quickFieldNames, *contentFieldNames;
 
   struct {
     int requiresFolderSelect:1;
@@ -126,6 +126,10 @@
 
 - (NSException *) deleteFolder;
 
+- (NSException *) updateQuickFields: (NSDictionary *) _fields
+                        whereColumn: (NSString *) _colname
+                          isEqualTo: (id) _value;
+
 - (NSArray *) fetchFields: (NSArray *) _flds 
        fetchSpecification: (EOFetchSpecification *) _fs;
 - (NSArray *) fetchFields: (NSArray *) fields
