@@ -1,6 +1,6 @@
 /* SOGoCache.h - this file is part of SOGo
  *
- * Copyright (C) 2008-2010 Inverse inc.
+ * Copyright (C) 2008-2011 Inverse inc.
  *
  * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
  *         Ludovic Marcotte <lmarcotte@inverse.ca>
@@ -44,6 +44,7 @@
   NSMutableDictionary *localCache;
   NSMutableDictionary *imap4Connections;
   NSMutableDictionary *cache;
+  BOOL requestsCacheEnabled;
   NSMutableDictionary *users;
   NSMutableDictionary *groups;
   float cleanupInterval;
@@ -52,11 +53,15 @@
 
 + (SOGoCache *) sharedCache;
 
+- (void) disableRequestsCache;
+
 - (void) killCache;
 
 - (void) registerObject: (id) object
 	       withName: (NSString *) name
 	    inContainer: (SOGoObject *) container;
+- (void) unregisterObjectWithName: (NSString *) name
+                      inContainer: (SOGoObject *) container;
 - (id) objectNamed: (NSString *) name
        inContainer: (SOGoObject *) container;
 
@@ -92,7 +97,9 @@
                 forLogin: (NSString *) login;
 - (NSString *) userSettingsForLogin: (NSString *) theLogin;
 
-/* CAS support */
+//
+// CAS support
+//
 - (NSString *) CASTicketFromIdentifier: (NSString *) identifier;
 - (NSString *) CASSessionWithTicket: (NSString *) ticket;
 - (void) setCASSession: (NSString *) casSession
@@ -103,9 +110,11 @@
 - (void) setCASPGTId: (NSString *) pgtId
            forPGTIOU: (NSString *) pgtIou;
 
+//
+// ACL caching support
+//
 - (void) setACLs: (NSDictionary *) theACLs
 	 forPath: (NSString *) thePath;
-
 - (NSMutableDictionary *) aclsForPath: (NSString *) thePath;
 
 @end
