@@ -16,20 +16,19 @@ function initLogin() {
     var about = $("about");
     if (about) {
         about.observe("click", function(event) {
-                                  $("aboutBox").show();
-                                  event.stop() });
-
+                if (!$("aboutBox").visible())
+                    Effect.SlideDown("aboutBox", { queue: { position: 'end', scope: 'aboutscope', limit: 2 } });
+                event.stop(); });
         var aboutClose = $("aboutClose");
         aboutClose.observe("click", function(event) {
-                                  $("aboutBox").hide();
-                                  event.stop() });
+                Effect.SlideUp("aboutBox", { duration: 2.0, queue: { position: 'end', scope: 'aboutscope', limit: 2 } });
+                event.stop() });
     }
 
     var submit = $("submit");
     submit.observe("click", onLoginClick);
 
     var userName = $("userName");
-    userName.focus();
     userName.observe("keydown", onFieldKeyDown);
 
     var passw = $("password");
@@ -40,6 +39,11 @@ function initLogin() {
 
     var submitBtn = $("submit");
     submitBtn.disabled = false;
+
+    if (userName.value.empty())
+        userName.focus();
+    else
+        passw.focus();
 }
 
 function onFieldKeyDown(event) {
@@ -62,6 +66,8 @@ function onLoginClick(event) {
     var language = $("language");
     var domain = $("domain");
 
+    SetLogMessage("errorMessage");
+
     if (userName.length > 0 && password.length > 0) {
         this.disabled = true;
         startAnimation($("animation"));
@@ -80,6 +86,9 @@ function onLoginClick(event) {
                            : ("&language=" + language.value));
         if (domain)
             parameters += "&domain=" + domain.value;
+        if ($("rememberLogin").checked)
+            parameters += "&rememberLogin=1";
+
         /// Discarded as it seems to create a cookie for nothing. To discard
         //  a cookie in JS, have a look here: http://www.quirksmode.org/js/cookies.html
         //document.cookie = "";\
